@@ -1,6 +1,6 @@
 #' Generate simulation data set
 #'
-#' @description \code{gen.sim.data} generates data from the following model 
+#' @description \code{gen.sim.data} generates data from the following model
 #' Y = X_0 Beta_0^T + X_1 Beta_1^T + Z Gamma^T + E Sigma^{1/2},
 #' Z|X_0, X_1 = X_0 Alpha_0^T + X_1 Alpha_1^T + D,
 #' cov(X_0, X_1) ~ Sigma_X
@@ -34,9 +34,9 @@
 #' \item{beta.nonzero.pos}{the nonzero positions in beta}
 #' \item{r}{number of confounders}
 #' }
-#' 
+#'
 #' @import stats
-#' 
+#'
 #' @export
 #'
 gen.sim.data <- function(n,
@@ -75,6 +75,9 @@ gen.sim.data <- function(n,
         beta[beta.nonzero.pos, ] <- beta.strength
         ## an alternative strategy:
         ## beta[beta.nonzero.pos, ] <- beta.strength * rnorm(p*beta.nonzero.frac)
+    } else {
+        beta.nonzero.pos <- which(beta != 0)
+        beta.nonzero.frac <- length(beta.nonzero.pos) / p
     }
 
     ## generate a Gamma if it is NULL
@@ -82,7 +85,7 @@ gen.sim.data <- function(n,
         Gamma <- matrix(rnorm(p*r), p, r)
 ### add the next line if you want to make Gamma very correlated with beta
         if(sum(beta^2) != 0) {
-            Gamma[,1] <- beta * Gamma.beta.cor / sqrt(sum(beta^2)) * sqrt(p) + sqrt(1 - Gamma.beta.cor^2) * rnorm(p)
+            Gamma[,1] <- beta[, 1] * Gamma.beta.cor / sqrt(sum(beta[, 1]^2)) * sqrt(p) + sqrt(1 - Gamma.beta.cor^2) * rnorm(p)
         }
         Gamma <- t(t(qr.Q(qr(Gamma))) * sample(c(-1, 1), r, replace = T))
         Gamma <- t(t(Gamma) * Gamma.strength)
@@ -139,17 +142,17 @@ gen.sim.data <- function(n,
 
 }
 
-# 
+#
 # #' Simulation
 # #'
 # cate.simulation.example <- function() {
-# 
+#
 #     power <- function(p.value, sig.level = 0.05) {
 #         sum(p.value < sig.level) / length(p.value)
 #     }
-# 
+#
 #     library(corpcor)
-# 
+#
 #     settings <- expand.grid(n = c(100),
 #                             p = c(1000),
 #                             r = c(2, 5),
@@ -167,26 +170,26 @@ gen.sim.data <- function(n,
 #                      expand.grid(adj.method = c("RUV4", "RUVinv", "leapp", "sva"),
 #                                  fa.method = "ml",
 #                                  calibration = TRUE))
-# 
+#
 #     niter <- 10
-# 
+#
 #     df <- data.frame(matrix(0, nrow(settings) * (nrow(methods) + 1) * niter,
 #                             ncol(settings) + ncol(methods) + 3))
 #     names(df) <- c(names(settings), names(methods), "type.I.error", "power", "fdp")
-# 
+#
 #     i <- 0
 #     t0 <- proc.time()[3]
 #     for (setting.ind in 1:nrow(settings)) {
-# 
+#
 #         setting <- settings[setting.ind,]
 # 		print(setting)
-# 
+#
 #         for (iter in 1:niter) {
-# 
+#
 #             print(iter)
-# 
+#
 #             i <- i + 1
-# 
+#
 #             n <- setting$n
 #             p <- setting$p
 #             r <- setting$r
@@ -202,12 +205,12 @@ gen.sim.data <- function(n,
 #                                  seed = (iter *  274876858367) %% 1000000)
 #             data$X0 <- cbind(rep(1, n), data$X0)
 #             nc <- sample(data$beta.zero.pos, 30)
-# 
+#
 #             #save(data, file = "puzzle.rda")
-# 
+#
 #                                         # oracle
 #             output <- lm(data$Y ~ data$X1 + data$Z - 1)
-# 
+#
 #             s <- summary(output)
 #             t <- sapply(1:ncol(data$Y), function(j) {s[[j]]$coefficients[1,3]})
 #             p.value <- 2 * (1 - pnorm(abs(t)))
@@ -215,19 +218,19 @@ gen.sim.data <- function(n,
 #             pow <- power(p.value[data$beta.nonzero.pos])
 #             discoveries <- which(p.adjust(p.value, "BH") < 0.2)
 #             fdp <- length(setdiff(discoveries, data$beta.nonzero.pos)) / max(length(discoveries), 1)
-# 
+#
 #             df[i, ] <- c(setting, 0, 0, 0, type.I.error, pow, fdp)
-# 
+#
 #             for (method.ind in 1:nrow(methods)) {
 #                 method <- methods[method.ind, ]
-# 
+#
 #                 i <- i + 1
-# 
+#
 #                 if ((i %% 100) == 0) {
 #                     print(paste("Time left:",
 #                                 (proc.time()[3] - t0) / i * (nrow(df) - i)))
 #                 }
-# 
+#
 #                 adj.method <- method$adj.method
 #                 if (as.character(method$adj.method) == "nc.no.correction") {
 #                     adj.method <- "nc"
@@ -264,12 +267,12 @@ gen.sim.data <- function(n,
 #                 pow <- power(output$beta.p.value[data$beta.nonzero.pos])
 #                 discoveries <- which(p.adjust(output$beta.p.value, "BH") < 0.2)
 #                 fdp <- length(setdiff(discoveries, data$beta.nonzero.pos)) / max(length(discoveries), 1)
-# 
+#
 #                 df[i, ] <- c(setting, method, type.I.error, pow, fdp)
 #             }
 #         }
 #     }
-# 
+#
 #     library(reshape2)
 #     dff <- melt(df, id = names(df)[1:9])
 #     library(ggplot2)
@@ -281,17 +284,17 @@ gen.sim.data <- function(n,
 #     cate.plot <- ggplot(subset(dff, alpha.strength == 1 & Gamma.beta.cor == 0 & beta.zero.frac == 0.05)) + aes(x = method) + geom_boxplot(aes(y = value)) + facet_grid(r~variable) + geom_hline(yintercept = 0.05, linetype = "dashed", col = "red") + geom_hline(yintercept = 0.2, linetype = "dashed", col = "red") + theme(axis.text.x = element_text(angle = 15))
 #     cate.plot
 #     ggsave("cate.pdf", cate.plot)
-# 
+#
 # }
-# 
-# 
+#
+#
 # cate.demo <- function(data.set = c("gender", "alzheimers", "COPD")) {
-# 
+#
 #     require(MASS)
 #     library(robustbase)
 #     library(ggplot2)
 #     library(GEOquery)
-# 
+#
 #     if (data.set == "gender") {
 #         library(ruv.data.gender.sm)
 #         data(gender.sm)
@@ -319,7 +322,7 @@ gen.sim.data <- function(n,
 #         data$Z <- cbind(rep(1, nrow(Y)), X[, -3])
 #         data$pctl <- rep(FALSE, nrow(Y))
 #     }
-# 
+#
 #     if (data.set == "gender") {
 #         output.naive <- cate(data$X, data$Y,
 #                              matrix(1, nrow(data$Y), 1),
@@ -327,7 +330,7 @@ gen.sim.data <- function(n,
 #                              adj.method = "naive",
 #                              r = 0,
 #                              calibrate = FALSE)
-# 
+#
 #         xlow <- switch(data.set,
 #                        gender = -1,
 #                        alzheimers = -4,
@@ -344,19 +347,19 @@ gen.sim.data <- function(n,
 #                         gender = 5,
 #                         alzheimers = 0.6,
 #                         COPD = 0.13)
-# 
+#
 #         plot.naive <- ggplot() + aes(x = output.naive$beta.t, y = ..density..) + geom_histogram(binwidth = 0.05 * xup / 2, colour = "black", fill = "white") + xlim(c(xlow, xup)) + geom_line(aes(x = seq(xlow, xup, 0.01), y = dnorm(seq(xlow, xup, 0.01), median(output.naive$beta.t), mad(output.naive$beta.t))), col = "violetred3", size = 1) + geom_text(aes(x = xtext, y = ytext, label = paste0("N(", signif(median(output.naive$beta.t), 2),",", signif(mad(output.naive$beta.t), 2), "^2)")), col = "violetred3", show_guide= FALSE, size = 7) + xlab("t-statistics") + ylab("density") + theme_bw(base_size = 20)
 #         plot.naive
 #         ggsave(paste0("../../plots/", data.set, "-naive.pdf"), plot.naive)
 #     }
-# 
+#
 #     output.batch <- cate(data$X, data$Y,
 #                          data$Z,
 #                          fa.method = "ml",
 #                          adj.method = "naive",
 #                          r = 0,
 #                          calibrate = FALSE)
-# 
+#
 #     xlow <- switch(data.set,
 #                    gender = -1,
 #                    alzheimers = -4,
@@ -373,20 +376,20 @@ gen.sim.data <- function(n,
 #                     gender = 1.3,
 #                     alzheimers = 0.6,
 #                     COPD = 0.13)
-# 
+#
 #     plot.batch <- ggplot() + aes(x = output.batch$beta.t, y = ..density..) + geom_histogram(binwidth = 0.05 * xup / 2, colour = "black", fill = "white") + xlim(c(xlow, xup)) + geom_line(aes(x = seq(xlow, xup, 0.01), y = dnorm(seq(xlow, xup, 0.01), median(output.batch$beta.t), mad(output.batch$beta.t))), col = "violetred3", size = 1) + geom_text(aes(x = xtext, y = ytext, label = paste0("N(", signif(median(output.batch$beta.t), 2),",", signif(mad(output.batch$beta.t), 2), "^2)")), col = "violetred3", show_guide= FALSE, size = 7) + xlab("t-statistics") + ylab("density") + theme_bw(base_size = 20)
 #     plot.batch
 #     ggsave(paste0("../../plots/", data.set, "-batch.pdf"), plot.batch)
-# 
+#
 #                                         # confounder adjustment
 #     r.max <- switch(data.set,
 #                     gender = 40,
 #                     alzheimers = 20,
 #                     COPD = 60)
 #     summary.statistics <- matrix(0, r.max + 1, 9)
-# 
+#
 #     library(moments)
-# 
+#
 #     for (r in 0:r.max) {
 #         print(r)
 #         if (r == 0) {
@@ -402,7 +405,7 @@ gen.sim.data <- function(n,
 #                            nc.var.correction = TRUE,
 #                            calibrate = FALSE)
 #         }
-# 
+#
 #         summary.statistics[r+1, ] <- c(
 #              length(which( 1 - pnorm(abs(output$beta.t - median(output$beta.t)) / mad(output$beta.t)) < 0.005)),
 #             length(intersect(which( 1 - pnorm(abs(output$beta.t - median(output$beta.t)) / mad(output$beta.t)) < 0.005), which(data$pctl))),
@@ -410,12 +413,12 @@ gen.sim.data <- function(n,
 #             mean(output$beta.t), median(output$beta.t),
 #             sd(output$beta.t), mad(output$beta.t),
 #             skewness(output$beta.t), mc(output$beta.t))
-# 
+#
 #     }
-# 
+#
 #     summary.statistics <- cbind(0:r.max, summary.statistics)
 #     colnames(summary.statistics) <- c("r", "#sig.", "X/Y", "top 100", "mean", "median", "sd", "mad", "skewness", "medcouple")
-# 
+#
 #     library(xtable)
 #     rows <- switch(data.set,
 #                    gender = c(1:6,8,11,16,21,26,31,41),
@@ -426,7 +429,7 @@ gen.sim.data <- function(n,
 #                  display = c(rep("d", 2), rep("fg", 6), rep("d", 3)),
 #                  digits = c(0,0,2,2,3,3,3,2,0,0,0),
 #                  caption = data.set), include.rownames = FALSE)
-# 
+#
 #     r <- switch(data.set,
 #                 gender = 25,
 #                 alzheimers = 11,
@@ -443,27 +446,27 @@ gen.sim.data <- function(n,
 #     plot.output <- ggplot() + aes(x = as.vector(output$beta.t), y = ..density..) + geom_histogram(binwidth = 0.2, colour = "black", fill = "white") + xlim(c(-6, 6)) + ylim(c(0, 0.35)) + geom_line(aes(x = seq(-6, 6, 0.01), y = dnorm(seq(-6, 6, 0.01), median(output$beta.t), mad(output$beta.t))), col = "violetred3", size = 1) + geom_text(aes(x = 3, y = 0.3, label = paste0("N(", signif(median(output$beta.t), 2),",", signif(mad(output$beta.t), 3), "^2)")), col = "violetred3", show_guide= FALSE, size = 7) + xlab("statistics") + ylab("density") + theme_bw(base_size = 20)
 #     plot.output
 #     ggsave(paste0("../../plots/", data.set, "-output.pdf"), plot.output)
-# 
+#
 # }
-# 
-# 
+#
+#
 # bcv.plot <- function() {
 #     load("bcvResult.rda")
 #     df <- data.frame(r = as.numeric(names(results$bcvErr.gender)),
 #                      error = results$bcvErr.gender/results$bcvErr.gender[1])
 #     plot.gender <- ggplot(df) + aes(x = r, y = error) + geom_point(size = 3, shape = 1) + geom_line() + theme_bw(base_size = 18) + scale_y_log10(breaks = c(0.1, 0.2, 0.5, 1)) + ylab("relative BCV MSE") + xlab("r") + geom_point(aes(x = r[which.min(error)], y = min(error)), col = "violetred3", size = 3)
 #     ggsave("../../plots/gender-bcv.pdf", plot.gender)
-# 
+#
 #     df <- data.frame(r = as.numeric(names(results$bcvErr.alzheimer)),
 #                      error = results$bcvErr.alzheimer/results$bcvErr.alzheimer[1])
 #     plot.alzheimers <- ggplot(df) + aes(x = r, y = error) + geom_point(size = 3, shape = 1) + geom_line() + theme_bw(base_size = 18) + scale_y_log10(breaks = c(0.1, 0.2, 0.5, 1)) + ylab("relative BCV MSE") + xlab("r") + geom_point(aes(x = r[which.min(error)], y = min(error)), col = "violetred3", size = 3)
 #     plot.alzheimers
 #     ggsave("../../plots/alzheimers-bcv.pdf", plot.alzheimers)
-# 
+#
 #     df <- data.frame(r = as.numeric(names(results$bcvErr.COPD)),
 #                      error = results$bcvErr.COPD/results$bcvErr.COPD[1])
 #     plot.COPD <- ggplot(df) + aes(x = r, y = error) + geom_point(size = 3, shape = 1) + geom_line() + theme_bw(base_size = 18) + scale_y_log10(breaks = c(0.4, 0.5, 0.8, 1)) + ylab("relative BCV MSE") + xlab("r") + geom_point(aes(x = r[which.min(error)], y = min(error)), col = "violetred3", size = 3)
 #     plot.COPD
 #     ggsave("../../plots/COPD-bcv.pdf", plot.COPD)
-# 
+#
 # }
